# -*- coding: utf-8 -*-
from django.core import serializers
from django.http import HttpResponse

from protocolo.cadastro.models import Municipio
from protocolo.cadastro.models import Cliente
from protocolo.cadastro.models import Mes


def get_meses_ajax(request):
    """ Retorna todos os meses do ano informado que possuem clientes
    configurados.
    """
    ano_id = request.GET['id_ano']

    retorno = []
    retorno = Mes.objects.filter(
        tipoclienteconfiguracao__ano__id=ano_id
    ).distinct()

    meses = serializers.serialize(
        'json',
        retorno,
        ensure_ascii=False
    )

    return HttpResponse(meses, mimetype="text/javascript")


def get_clientes_municipio_ajax(request):
    """ Retorna todos os clientes do município que possuam uma configuração.

    Retorna todos os clientes do município que possuam uma configuração no mês
    e ano informados e ainda tenha a flag ativo setada para true.
    """
    municipio_id = request.GET['id_municipio']
    ano_id = request.GET['id_ano']
    mes_id = request.GET['id_mes']

    retorno = Cliente.objects.filter(
        municipio__id__exact=municipio_id,
        ativo=True
    ).filter(
        tipo_cliente__tipoclienteconfiguracao__mes=mes_id,
        tipo_cliente__tipoclienteconfiguracao__ano=ano_id
    ).distinct()

    clientes_municipio = serializers.serialize(
        'json',
        retorno,
        ensure_ascii=False
    )

    return HttpResponse(clientes_municipio, mimetype="text/javascript")


def get_municipios_ajax(request):
    """ Retorna todos os municípios que no mês e ano informados possuem
    configuração de tipo de cliente e possuem pelo menos um cliente ativo.
    """
    ano_id = request.GET['id_ano']
    mes_id = request.GET['id_mes']

    retorno = Municipio.objects.filter(
        cliente__tipo_cliente__tipoclienteconfiguracao__mes=mes_id,
        cliente__tipo_cliente__tipoclienteconfiguracao__ano=ano_id,
        cliente__ativo=True
    ).distinct()

    municipios = serializers.serialize(
        'json',
        retorno,
        ensure_ascii=False
    )

    return HttpResponse(municipios, mimetype="text/javascript")
