# -*- coding: utf-8 -*-

from django.contrib import admin
from django.db.models import Max

from configuracao.models import TipoClienteConfiguracao
from configuracao.models import ClienteConfiguracao
from configuracao.models import IndiceMetaTipoCliente
from configuracao.forms import TipoClienteConfiguracaoForm
from cadastro.models import Ano
from cadastro.models import Mes


def copiar_configuracao_ano_seguinte(modeladmin, request, queryset):
    """ Copia uma configuração para o ano seguinte.
    """
    if type(modeladmin) == TipoClienteConfiguracaoAdmin:
        for configuracao in queryset:
            proximo_ano, criado = Ano.objects.get_or_create(ano=unicode(int(configuracao.ano.ano) + 1))
            nova_configuracao, criado = TipoClienteConfiguracao.objects.get_or_create(
                tipo_cliente = configuracao.tipo_cliente,
                ano = proximo_ano,
                mes = configuracao.mes,
            )
            nova_configuracao.tipos_relatorio = configuracao.tipos_relatorio.all()
            nova_configuracao.indices = configuracao.indices.all()
            nova_configuracao.save()

    if type(modeladmin) == IndiceMetaTipoClienteAdmin:
        for configuracao in queryset:
            proximo_ano, criado = Ano.objects.get_or_create(ano=unicode(int(configuracao.ano.ano) + 1))
            nova_configuracao, criado = IndiceMetaTipoCliente.objects.get_or_create(
                ano = proximo_ano,
                tipo_percentual = configuracao.tipo_percentual,
                valor = configuracao.valor,
                indice = configuracao.indice,
            )
    if type(modeladmin) == ClienteConfiguracaoAdmin:
        for configuracao in queryset:
            proximo_ano, criado = Ano.objects.get_or_create(ano=unicode(int(configuracao.ano.ano) + 1))
            nova_configuracao, criado = ClienteConfiguracao.objects.get_or_create(
                ano = proximo_ano,
                tipo_percentual = configuracao.tipo_percentual,
                valor = configuracao.valor,
                indice = configuracao.indice,
                cliente = configuracao.cliente,
            )
copiar_configuracao_ano_seguinte.short_description = \
'Copiar para o ano seguinte.'

def copiar_configuracao_mes_seguinte(modeladmin, request, queryset):
    """ Copia uma configuração para o mês seguinte.
    """
    if type(modeladmin) == TipoClienteConfiguracaoAdmin:
        for configuracao in queryset:
            ultimo_mes = Mes.objects.aggregate(Max('codigo'))
            
            if int(configuracao.mes.codigo) < int(ultimo_mes['codigo__max']):
                mes = unicode(int(configuracao.mes.codigo)+1)
                if len(mes) == 1:
                    codigo_mes = '0' + mes
                else:
                    codigo_mes = mes

                proximo_mes, criado = Mes.objects.get_or_create(codigo=codigo_mes)
                
                nova_configuracao, criado = TipoClienteConfiguracao.objects.get_or_create(
                    tipo_cliente = configuracao.tipo_cliente,
                    ano = configuracao.ano,
                    mes = proximo_mes,
                )
                nova_configuracao.tipos_relatorio = configuracao.tipos_relatorio.all()
                nova_configuracao.indices = configuracao.indices.all()
                nova_configuracao.save()
copiar_configuracao_mes_seguinte.short_description = \
'Copiar para o mes seguinte.'


class IndiceMetaTipoClienteAdmin(admin.ModelAdmin):
    list_display = ('ano', 'indice', 'tipo_percentual', 'valor')
    list_filter = ('ano', 'indice', 'tipo_percentual')
    fieldsets = (
        (None, {
            'fields': ('ano', ('indice', 'tipo_percentual', 'valor'))
        }),
    )
    actions = [copiar_configuracao_ano_seguinte]


class TipoClienteConfiguracaoAdmin(admin.ModelAdmin):
    form = TipoClienteConfiguracaoForm
    list_display = ('tipo_cliente', 'mes', 'ano')
    list_filter = ('tipo_cliente', 'mes', 'ano')
    actions = [copiar_configuracao_ano_seguinte, copiar_configuracao_mes_seguinte]


class ClienteConfiguracaoAdmin(admin.ModelAdmin):
    list_display = ('cliente', 'ano', 'indice', 'tipo_percentual', 'valor')
    list_filter = ('ano', 'cliente')
    fieldsets = (
        (None, {
            'fields': ('ano', 'cliente',('indice', 'tipo_percentual', 'valor'))
        }),
    )
    actions = [copiar_configuracao_ano_seguinte]

admin.site.register(TipoClienteConfiguracao, TipoClienteConfiguracaoAdmin)
admin.site.register(ClienteConfiguracao, ClienteConfiguracaoAdmin)
admin.site.register(IndiceMetaTipoCliente, IndiceMetaTipoClienteAdmin)
