# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings

from protocolo.cadastro.models import Cliente
from protocolo.cadastro.models import TipoCliente
from protocolo.cadastro.models import TipoRelatorio
from protocolo.cadastro.models import Mes
from protocolo.cadastro.models import Ano
from protocolo.cadastro.models import IndiceMetaBase
from protocolo.cadastro.models import IndiceCliente
from protocolo.cadastro.models import IndiceTipoCliente

class TipoClienteConfiguracao(models.Model):
    tipo_cliente = models.ForeignKey(TipoCliente)
    ano = models.ForeignKey(Ano)
    mes = models.ForeignKey(Mes)
    tipos_relatorio = models.ManyToManyField(
        TipoRelatorio,
        verbose_name='tipos de relatórios',
    )
    indices = models.ManyToManyField(
        IndiceTipoCliente,
        null=True,
        blank=True,
    )

    class Meta:
        db_table = 'tipo_cliente_configuracao'
        verbose_name = 'relatórios e índices para tipo de cliente'
        verbose_name_plural = 'relatórios e índices para tipos de cliente'
        unique_together = (('tipo_cliente', 'ano', 'mes'),)

    def __unicode__(self):
        if settings.CAPITALIZE:
            return self.tipo_cliente.nome.capitalize()
        else:
            return self.tipo_cliente.nome


class ClienteConfiguracao(IndiceMetaBase):
    cliente = models.ForeignKey(Cliente, limit_choices_to={'ativo': True})
    indice = models.ForeignKey(IndiceCliente)

    class Meta:
        db_table = 'cliente_configuracao'
        verbose_name = 'índice e meta para cliente'

    def __unicode__(self):
        return self.cliente.nome


class IndiceMetaTipoCliente(IndiceMetaBase):
    """ Metas de índice para tipo de cliente.
    """
    indice = models.ForeignKey(IndiceTipoCliente)

    class Meta:
        db_table = 'indice_meta_tipo_cliente'
        verbose_name = 'meta de índice para tipos de cliente'
        verbose_name_plural = 'metas de índices para tipos de cliente'

    def __unicode__(self):
        return self.indice.nome

