# -*- coding: utf-8 -*-

from django.contrib import admin

from protocolo.protocolos.models import Arquivo
from protocolo.protocolos.models import ProtocoloArquivo
from protocolo.protocolos.models import ClienteIndiceInformado
from protocolo.protocolos.models import TipoClienteIndiceInformado
from protocolo.cadastro.models import TipoRelatorio
from protocolo.cadastro.models import IndiceTipoCliente
from protocolo.cadastro.models import IndiceCliente

from protocolo.protocolos.forms import TipoClienteIndiceInformadoForm
from protocolo.protocolos.forms import ArquivoForm
from protocolo.protocolos.forms import ClienteIndiceInformadoForm

class ArquivoInline(admin.TabularInline):
    form = ArquivoForm
    model = Arquivo

    def get_formset(self, request, obj=None, **kwargs):
        self.extra = TipoRelatorio.objects.count()
        self.max_num = self.extra
        return super(ArquivoInline, self).get_formset(request, obj=obj, **kwargs)


class ClienteIndiceInformadoInline(admin.TabularInline):
    model = ClienteIndiceInformado
    form = ClienteIndiceInformadoForm
    fields = ('indice', 'valor')

    def get_formset(self, request, obj=None, **kwargs):
        self.extra = IndiceCliente.objects.count()
        self.max_num = self.extra
        return super(ClienteIndiceInformadoInline, self).get_formset(
            request,
            obj=obj,
            **kwargs
        )


class TipoClienteIndiceInformadoInline(admin.TabularInline):
    model = TipoClienteIndiceInformado
    form = TipoClienteIndiceInformadoForm
    fields = ('indice', 'valor')

    def get_formset(self, request, obj=None, **kwargs):
        self.extra = IndiceTipoCliente.objects.count()
        self.max_num = self.extra
        return super(TipoClienteIndiceInformadoInline, self).get_formset(
            request,
            obj=obj,
            **kwargs
        )

class ProtocoloArquivoAdmin(admin.ModelAdmin):
    #form = ProtocoloArquivoForm
    exclude = ('protocolo',)
    list_display = (
        'ano',
        'mes',
        'municipio',
        'cliente',
        'proprietario',
        'educacao',
        'saude',
        'fundeb60',
        'pessoal_exec'
    )
    ordering = ['-ano',]
    list_filter = ['ano', 'mes', 'municipio']
    inlines = [
        ArquivoInline,
        TipoClienteIndiceInformadoInline,
        ClienteIndiceInformadoInline
    ]

    def save_model(self, request, obj, form, change):
        """ Víncula o proprietário ao registro.
        """
        if getattr(obj, 'proprietario', None) is None:
            obj.proprietario = request.user
        obj.last_modified_by = request.user
        obj.save()

    def queryset(self, request):
        """ Somente exibe os registros do proprietário(super usuário pode ver
        todos os registro).
        """
        qs = super(ProtocoloArquivoAdmin, self).queryset(request)

        if(request.user.is_superuser):
            return qs

        return qs.filter(proprietario=request.user)

    # TODO: É necessário criar uma forma de definir os métodos para os índices em
    #tempo de execução.
    def educacao(self, obj):
        return TipoClienteIndiceInformado.objects.get(
            protocolo_arquivo=obj,
            indice__nome='Educação').valor
    educacao.short_description = 'Educação'

    def saude(self, obj):
        return TipoClienteIndiceInformado.objects.get(
            protocolo_arquivo=obj,
            indice__nome='Saúde').valor
    saude.short_description = 'Saúde'

    def fundeb60(self, obj):
        return TipoClienteIndiceInformado.objects.get(
            protocolo_arquivo=obj,
            indice__nome='FUNDEB 60').valor
    fundeb60.short_description = 'FUNDEB 60'

    def pessoal_exec(self, obj):
        return TipoClienteIndiceInformado.objects.get(
            protocolo_arquivo=obj,
            indice__nome__icontains='executivo').valor
    pessoal_exec.short_description = 'Pessoal - Executivo'


admin.site.register(ProtocoloArquivo, ProtocoloArquivoAdmin)
