# -*- coding: utf-8 -*-

import re

from django import forms

from protocolos.models import Arquivo
from protocolos.models import TipoClienteIndiceInformado
from protocolos.models import ClienteIndiceInformado
from utils.utils import valida_arquivo_pdf


class TipoClienteIndiceInformadoForm(forms.ModelForm):
    class Meta:
        model = TipoClienteIndiceInformado

    def clean_valor(self):
        valor = self.cleaned_data['valor']

        if (valor < 0.0) or (valor > 100.0):
            raise forms.ValidationError(
                u'Os índices devem ter valor entre 0.0 e 100.0'
            )

        return valor


class ClienteIndiceInformadoForm(forms.ModelForm):
    class Meta:
        model = ClienteIndiceInformado

    def clean_valor(self):
        valor = self.cleaned_data['valor']

        if (valor < 0.0) or (valor > 100.0):
            raise forms.ValidationError(
                u'Os índices devem ter valor entre 0.0 e 100.0'
            )

        return valor


class ArquivoForm(forms.ModelForm):
    class Meta:
        model = Arquivo

    class Media:
        js = ('js/protocolos/arquivo/controla_campos.js',)

    def clean_arquivo(self):
        """ Renomeia o arquivo e verifica a extensão. """
        arquivo = None

        try:
            arquivo = self.cleaned_data['arquivo']
        except:
            raise forms.ValidationError(
                u'Erro ao carregar o arquivo. Contate o suporte técnico'
            )

        if re.split('\.', arquivo.name.lower())[1] != "pdf":
            raise forms.ValidationError(
                u'Só é permitido o envio de arquivos pdf.'
            )

        # Só valida o arquivo se ele for alterado(a adição implica em alteração)
        if(self.has_changed()):
            if not(valida_arquivo_pdf(arquivo.temporary_file_path())):
                raise forms.ValidationError(
                    u'Só é permitido o envio de arquivos pdf.'
                )

        return arquivo

