# -*- coding: utf-8 -*-

from django import forms
from django.shortcuts import HttpResponseRedirect
from django.contrib.formtools.wizard import FormWizard

from cadastro.models  import Ano
from cadastro.models  import Mes
from cadastro.models  import Municipio
from utils.constantes import CONDICAO_RELATORIO_INDICES
from utils.constantes import CONDICAO_RELATORIO_ARQUIVOS

class PreFiltroBase(forms.Form):
    ano = forms.ModelChoiceField(Ano.objects.all())
    mes = forms.ModelChoiceField(Mes.objects.all())


class PreFiltroFormRelatorioNaoInformado(PreFiltroBase):
    municipio = forms.ModelChoiceField(Municipio.objects.all(), required=False)
    configurado = forms.BooleanField(
                                     required=False,
                                     label='Cliente sem configuração'
                        )
    condicao = forms.ChoiceField(
                                 label='Arquivos',
                                 choices=CONDICAO_RELATORIO_ARQUIVOS
            )

    def __init__(self, *args, **kwargs):
        super(PreFiltroFormRelatorioNaoInformado, self).__init__(*args, **kwargs)


class PreFiltroFormRelatorioForaMeta(PreFiltroBase):
    condicao = forms.ChoiceField(
                                 label='Índices',
                                 choices=CONDICAO_RELATORIO_INDICES
                )

    def __init__(self, *args, **kwargs):
        super(PreFiltroFormRelatorioForaMeta, self).__init__(*args, **kwargs)


class FiltroWizardRelatorioForaMeta(FormWizard):
    def done(self, request, form_list):
        ano = form_list[0].cleaned_data['ano'].id
        mes = form_list[0].cleaned_data['mes'].id
        condicao = form_list[0].cleaned_data['condicao']

        return HttpResponseRedirect(
            'relatorios/fora_meta/?ano_id=%s&mes_id=%s&condicao=%s' %\
            (ano, mes, condicao)
        )


class FiltroWizardRelatorioNaoInformado(FormWizard):
    def done(self, request, form_list):
        ano = form_list[0].cleaned_data['ano'].id
        mes = form_list[0].cleaned_data['mes'].id
        if form_list[0].cleaned_data['municipio']:
            municipio = form_list[0].cleaned_data['municipio'].id
        else:
            municipio = 0
        configurado = form_list[0].cleaned_data['configurado']
        condicao = form_list[0].cleaned_data['condicao']

        return HttpResponseRedirect(
            'relatorios/relatorio_nao_enviado/?ano_id=%s&mes_id=%s&municipio=%s&configurado=%s&condicao=%s'\
            % (ano, mes, municipio, configurado, condicao)
        )
