# -*- coding: utf-8 -*-

from django.shortcuts import render_to_response
from django.conf import settings
from django.core.paginator import Paginator
from django.core.paginator import EmptyPage
from django.core.paginator import InvalidPage
from django.contrib.auth.decorators import login_required
from django.contrib import messages 

from protocolos.models import ProtocoloArquivo
from configuracao.models import IndiceMetaTipoCliente
from configuracao.models import ClienteConfiguracao
from configuracao.models import TipoClienteConfiguracao
from cadastro.models import Cliente
from cadastro.models import Indice
from cadastro.models import Ano
from cadastro.models import Mes
from cadastro.models import TipoRelatorio
from utils.constantes import INDICE_TODOS
from utils.constantes import INDICE_CUMPRINDO
from utils.constantes import ARQUIVO_TODOS
from utils.constantes import ARQUIVO_ENTREGUE
from utils.constantes import ARQUIVO_PENDENTE
from django.template.context import RequestContext


@login_required
def get_relatorio_clientes_fora_meta(request):
    """ Envia os dados para montar o relatório dos clientes que não estão
    atingindo meta.

    Via FormWizard que está em: protocolos.forms.py o usuário primeiro irá
    informar os parâmetros, em seguida eles são enviados para este método que
    enviará os dados necessários para o template
    (relatorio_clientes_indice_fora_meta).
    """
    ano = request.GET['ano_id']
    mes = request.GET['mes_id']
    condicao = int(request.GET['condicao'])

    indices = Indice.objects.all()

    meta_indices_tipo_cliente = IndiceMetaTipoCliente.objects.filter(
        ano__id=ano,
    )

    meta_indice_cliente = ClienteConfiguracao.objects.filter(
        ano__id=ano,
    )

    protocolos = []
    protocolos_fora_meta = []
    
    if condicao == INDICE_TODOS:
        protocolos = ProtocoloArquivo.objects.filter(ano__id=ano, mes__id=mes,)
    elif condicao == INDICE_CUMPRINDO:
        for meta_indice in meta_indices_tipo_cliente:
            if meta_indice.tipo_percentual == 0:
                protocolos_fora_meta.append(
                    ProtocoloArquivo.objects.filter(
                        ano__id=ano,
                        mes__id=mes,).filter(
                        tipoclienteindiceinformado__valor__gte=meta_indice.valor,
                        tipoclienteindiceinformado__indice=meta_indice.indice
                        )
                )
            else:
                protocolos_fora_meta.append(
                                ProtocoloArquivo.objects.filter(
                        ano__id=ano,
                        mes__id=mes,).filter(
                        tipoclienteindiceinformado__valor__lte=meta_indice.valor,
                        tipoclienteindiceinformado__indice=meta_indice.indice
                        )
                )
    else:
        for meta_indice in meta_indices_tipo_cliente:
            if meta_indice.tipo_percentual == 0:
                protocolos_fora_meta.append(
                    ProtocoloArquivo.objects.filter(
                        ano__id=ano,
                        mes__id=mes,).filter(
                        tipoclienteindiceinformado__valor__lt=meta_indice.valor,
                        tipoclienteindiceinformado__indice=meta_indice.indice
                        )
                )
            else:
                protocolos_fora_meta.append(
                                ProtocoloArquivo.objects.filter(
                        ano__id=ano,
                        mes__id=mes,).filter(
                        tipoclienteindiceinformado__valor__gt=meta_indice.valor,
                        tipoclienteindiceinformado__indice=meta_indice.indice
                        )
                )

    if condicao != INDICE_TODOS:
        # a consulta pode trazer um array com mais de um objeto, por isso é
        #necessário realizar duas varreduras.
        for protocolo_fora_meta in protocolos_fora_meta:
            if protocolo_fora_meta:
                for protocolo in protocolo_fora_meta:
                    protocolos.append(protocolo)

    if protocolos:
        return render_to_response(
            'relatorios/relatorio_clientes_indice_fora_meta.html',
            {
                'protocolo_arquivo': protocolos,
                'meta_indices_tipo_cliente': meta_indices_tipo_cliente,
                'indices': indices,
                'meta_indice_cliente': meta_indice_cliente,
                'mes': protocolos[0].mes,
                'ano': protocolos[0].ano
            },
            context_instance=RequestContext(request)
        )
    else:
        messages.info(request, 'Não existem dados a serem exibidos.')

        return render_to_response(
            'relatorios/relatorio_clientes_indice_fora_meta.html',
            context_instance=RequestContext(request)
        )


@login_required
def get_relatorio_cliente_nao_informado(request):
    """ Envia os dados para montar o relatório dos clientes que não enviaram
    algum relatório exigido.

    Via FormWizard que está em: protocolos.forms.py o usuário primeiro irá
    informar os parâmetros, em seguida eles são enviados para este método que
    enviará os dados necessários para o template
    (relatorio_cliente_relatorio_nao_enviado.html).
    """
    ano = request.GET['ano_id']
    mes = request.GET['mes_id']
    municipio = request.GET['municipio']
    configurado = request.GET['configurado'].lower() == 'false'
    condicao = int(request.GET['condicao'])

    if municipio != '0':
        cliente_filtro = Cliente.objects.filter(ativo=True, municipio__id=municipio)
        protocolos_arquivo = ProtocoloArquivo.objects.filter(
            ano__id=ano,
            mes__id=mes,
            cliente__municipio__id=municipio)
    else:
        cliente_filtro = Cliente.objects.filter(ativo=True)
        protocolos_arquivo = ProtocoloArquivo.objects.filter(
            ano__id=ano,
            mes__id=mes)
        
    if configurado:
        tipos_cliente = TipoClienteConfiguracao.objects.filter(ano__id=ano, mes__id=mes)
        clientes_filtro = cliente_filtro.filter(tipo_cliente__in=tipos_cliente)
    else:
        clientes_filtro = cliente_filtro
        

    relatorios = TipoRelatorio.objects.filter(
        tipoclienteconfiguracao__ano__id=ano,
        tipoclienteconfiguracao__mes__id=mes
    ).distinct()

    all = 0

    try:
        all = request.GET['all']
    except:
        pass

    if all:
        paginator = Paginator(clientes_filtro, clientes_filtro.count())
    else:
        paginator = Paginator(clientes_filtro, settings.PAGINACAO)

    try:
        pagina = int(request.GET.get('pagina', '1'))
    except ValueError:
        pagina = 1

    try:
        clientes = paginator.page(pagina)
    except (EmptyPage, InvalidPage):
        clientes = paginator.page(paginator.num_pages)

    return render_to_response(
        'relatorios/relatorio_cliente_relatorio_nao_enviado.html',
        {
            'clientes': clientes,
            'ano': Ano.objects.get(id=ano),
            'mes': Mes.objects.get(id=mes),
            'relatorios': relatorios,
            'protocolos_arquivo': protocolos_arquivo,
            'condicao': condicao,
            'ARQUIVO_TODOS': ARQUIVO_TODOS,
            'ARQUIVO_ENTREGUE': ARQUIVO_ENTREGUE,
            'ARQUIVO_PENDENTE': ARQUIVO_PENDENTE
        },
        context_instance=RequestContext(request)
    )
